#
# spec file for package aws-efs-utils
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1600
%define pythons %{primary_python}
%else
%define pythons python311
%endif
%global _sitelibdir %{%{pythons}_sitelib}
Name:           aws-efs-utils
Version:        2.0.3
Release:        1.2
Summary:        Utilities for using the EFS file systems
License:        MIT
Group:          System/Management
URL:            https://github.com/aws/efs-utils
Source0:        %{url}/archive/v%{version}.tar.gz#/efs-utils-%{version}.tar.gz
Patch0:         disable_mount_efs_test.patch
Patch1:         harden_amazon-efs-mount-watchdog.service.patch
Patch2:         skip-styletest.patch
Patch3:         use_mock_from_unittest.patch
BuildRequires:  %{pythons}-attrs >= 17.4.0
BuildRequires:  %{pythons}-botocore >= 1.17.53
BuildRequires:  %{pythons}-coverage >= 4.5.4
BuildRequires:  openssl
#BuildRequires:  %{pythons}-flake8 >= 3.7.9
BuildRequires:  %{pythons}-flake8
BuildRequires:  %{pythons}-mccabe >= 0.6.1
BuildRequires:  %{pythons}-pbr >= 3.1.1
BuildRequires:  %{pythons}-pluggy >= 0.13.0
BuildRequires:  %{pythons}-py >= 1.11.0
BuildRequires:  %{pythons}-pycodestyle >= 2.5.0
BuildRequires:  %{pythons}-pyflakes >= 2.1.1
BuildRequires:  %{pythons}-pytest >= 4.6.7
BuildRequires:  %{pythons}-pytest-cov >= 2.8.1
BuildRequires:  %{pythons}-pytest-html >= 1.19.0
BuildRequires:  %{pythons}-pytest-metadata >= 1.7.0
BuildRequires:  %{pythons}-pytest-mock >= 1.11.2
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(systemd)
Requires:       nfs-utils
Requires:       stunnel >= 4.56
BuildArch:      noarch

%description
This package provides utilities for using the EFS file systems.

%prep
%setup -n efs-utils-%{version}
%patch -P 0 -p1
find . -name "*.py" -exec sed -i 's/env python3/python3/' {} +
%patch -P 1 -p1
%patch -P 2
%patch -P 3 -p1

%build
# No build required

%check
make test

%install
mkdir -p %{buildroot}%{_sysconfdir}/amazon/efs
mkdir -p %{buildroot}%{_unitdir}
install -p -m 644 %{_builddir}/efs-utils-%{version}/dist/amazon-efs-mount-watchdog.service %{buildroot}%{_unitdir}

mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%{_localstatedir}/log/amazon/efs
mkdir -p %{buildroot}%{_mandir}/man8
mkdir -p %{buildroot}%{_sysconfdir}/amazon/efs

install -p -m 644 %{_builddir}/efs-utils-%{version}/dist/efs-utils.conf %{buildroot}%{_sysconfdir}/amazon/efs
install -p -m 444 %{_builddir}/efs-utils-%{version}/dist/efs-utils.crt %{buildroot}%{_sysconfdir}/amazon/efs
install -p -m 755 %{_builddir}/efs-utils-%{version}/src/mount_efs/__init__.py %{buildroot}%{_sbindir}/mount.efs
install -p -m 755 %{_builddir}/efs-utils-%{version}/src/watchdog/__init__.py %{buildroot}%{_bindir}/amazon-efs-mount-watchdog
install -p -m 644 %{_builddir}/efs-utils-%{version}/man/mount.efs.8 %{buildroot}%{_mandir}/man8

# Create rc-link
for srv_name in %{buildroot}%{_unitdir}/*.service; do rc_name=$(basename -s '.service' $srv_name); ln -s service %{buildroot}%{_sbindir}/rc$rc_name; done

%pre
%service_add_pre amazon-efs-mount-watchdog.service

%post
%service_add_post amazon-efs-mount-watchdog.service

%preun
%service_del_preun amazon-efs-mount-watchdog.service

%postun
%service_del_postun amazon-efs-mount-watchdog.service

%files
%defattr(-,root,root,-)
%doc NOTICE README.md
%license LICENSE
%{_unitdir}/amazon-efs-mount-watchdog.service
%{_sysconfdir}/amazon
%config %{_sysconfdir}/amazon/efs/efs-utils.conf
%config %{_sysconfdir}/amazon/efs/efs-utils.crt
%{_sbindir}/mount.efs
%{_bindir}/amazon-efs-mount-watchdog
%{_sbindir}/rcamazon-efs-mount-watchdog
%{_var}/log/amazon
%{_mandir}/man8/mount.efs.8.gz

%changelog
* Wed Jul 31 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 2.0.3
  * Upgrade py version
  * Replace deprecated usage of datetime
- from version 2.0.2
  * Check for efs-proxy PIDs when cleaning tunnel state files
  * Add PID to log entries
- from version 2.0.1
  * Disable Nagle's algorithm for efs-proxy TLS mounts to improve latencies
- from version 2.0.0
  * Replace stunnel, which provides TLS encryptions for mounts, with efs-proxy,
    a component built in-house at AWS. Efs-proxy lays the foundation for upcoming
    feature launches at EFS.
- from version 1.36.0
  * Support new mount option: crossaccount, conduct cross account mounts via ip address.
    Use client AZ-ID to choose mount target.
- from version 1.35.2
  * Revert "Add warning if using older Version"
  * Support MacOS Sonoma
- Switch package to modern Python Stack on SLE-15
  * Use Python 3.11 on SLE-15 by default
  * Use primary Python version on Tumbleweed
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Tue Feb 13 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.35.1
  * Revert openssl requirement change
  * Revert "Update EFS Documentation: Clarify Current FIPS Compliance Status"
  * Update EFS Documentation: Clarify Current FIPS Compliance Status
  * test: Change repo urls in eol debian9 build
  * Check private key file size to skip generation
  * test: Fix pytest that failed since commit 3dd89ca
  * Fix should_check_efs_utils_version scope
  * Add warning if using old version
  * Add 'fsap' option as EFS-only option
* Fri Mar 31 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.35.0
  * Add parameters to allow mount fo pod impersonation feature in EFS CSI Driver
  * Updated the README with support of Oracle8 distribution
  * Readme troubleshooting section + table of contents
  * Add efs-utils Support for MacOS Ventura EC2 instances
* Wed Jan 25 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.34.5
  * Handle invalid entries in /proc/mounts
  * Detect invalid private key
* Tue Jan  3 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.34.4
  * Fix potential tlsport selection collision by using
    state file as tlsport lock file (bsc#1206737, CVE-2022-46174)
- Use RPM macros for directory paths (bsc#1191055)
* Fri Dec  2 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.34.3
  * Fix stunnel constantly restart issue when upgrading
    from 1.32.1 and before version to latest version
  * Fix race in stunnel port selection
  * Disable journal entry fetch from systemctl call
- from version 1.34.2
  * Fix potential issue on AL2 when watchdog trying to restart
    stunnel for the TLS mounts that existing before upgrade
- from version 1.34.1
  * Update Amazon Linux 2 platform to use namespaced stunnel5
* Tue Oct 18 2022 pgajdos@suse.com
- python-six is not required for build
  https://trello.com/c/MO53MocR/143-remove-python3-six
* Fri Sep 23 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.33.4 (bsc#1203170)
  * Fix the issue where watchdog sending signal to incorrect
    processes and add FIPS mode support
  * Apply additional check on awscredsuri option
- from version 1.33.3
  * Fix the potential stunnel hanging issue caused by full
    subprocess PIPE filled by stunnel log
  * Specify FIPS mode in configuration
  * Add separate env_path for macOS; Add comments
  * Update get-pip.py download url in README
- from version 1.33.2
  * Fix the incorrect path to generate read_ahead_kb config file
    and Bump the default tls port range from 400 to 1000
- Add patch to use unittest.mock instead of mock in testsuite
  * use_mock_from_unittest.patch
- Use relative URL in Source field
* Wed May 18 2022 pgajdos@suse.com
- version update to 1.33.1
  * Enable mount process to retry on failed or timed out mount.nfs command
  * use unittest.mock instead of mock
* Wed Apr 27 2022 pgajdos@suse.com
- version update to 1.32.1
  * Enable watchdog to check stunnel health periodically and restart
    hanging stunnel process when necessary.
- do not require python-mock for build
  https://trello.com/c/S6eADbii/64-remove-python-mock
* Wed Mar  9 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Remove redundant python3 dependency from Requires
- Update regular expression to fix python shebang
* Fri Feb 18 2022 Robert Schweikert <rjschwei@suse.com>
- Update to version 1.31.3 (bsc#1195916)
  + Add skip-styletest.patch
  - Style is enforced upstream and triggers unnecessary build version
    requirements
  + Allow specifying fs_id in cloudwatch log group name
  + Includes fix for stunnel path
* Wed Aug 11 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s). Added patch(es):
  * harden_amazon-efs-mount-watchdog.service.patch
* Thu Jun 24 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.31.2
  + Handle HTTPError and other unknown exception when fetching IMDS token
  + Support Oracle Enterprise Linux 8
- from version 1.31.1
  + Support fallback to mount with mount target ip address when DNS resolution fails
  + Bump py from 1.8.0 to 1.10.0
- from version 1.30.2
  + Add helper message when config file on instance is not latest
  + Fix the throughput regression due to read_ahead configuration change
    on Linux distribution with kernel version 5.4.x and above
- from version 1.30.1
  + Support mounting to specific AZ mount target
  + Revert "Support mounting to specific AZ mount target"
  + Support mounting to specific AZ mount target
  + Use regional AWS STS endpoints instead of the global endpoint to reduce latency
- from version 1.29.1-mac
  + Fix issue where state files are removed after mount on EC2
    instances running on MacOS Big Sur
  + Add support for EC2 Mac instances running macOS Big Sur
- from version 1.29.1
  + Update the python dependency to python3
  + Fix typo
- from version 1.28.2
  + Fix the issue that mounting with IAM authorization with
    iam role does not work with IMDSv2
- from version 1.28.1
  + Support publishing mount success/failure notification via CloudWatch log
  + filename of .deb-package now includes architecture
- from version 1.27.1
  + Merge PR #60 on GitHub. Adds support for AssumeRoleWithWebIdentity.
  + Add support for AssumeRoleWithWebIdentity
- from version 1.26.3
  + Fix an issue where watchdog crashed during restart because stunnel
    was killed and pid key was removed from state file
- from version 1.26.2
  + Fixes an issue with watchdog where it sometimes fails to restart stunnels in
    efs-csi-driver container * Fixes an issue where fs cannot be mounted with tls
    using systemd.automount-units due to mountpoint check
  + Revert "Fixes an issue with watchdog where it sometimes fails to restart stunnels
    in efs-csi-driver container"
  + Fixes an issue with watchdog where it sometimes fails to restart stunnels in
    efs-csi-driver container
  + Remove non-ascii character in dist/efs-utils.conf
- from version 1.25-3
  + Check if mountpoint is already mounted beforehand for tls mount
  + Bug fix and enhancement, support fedora
- from version 1.25-2
  + Fix python3 IAM role name encoded format, add optional
    override for stunnel log
  + Encode IAM role name to UTF-8
- from version 1.25-1
  + Create self-signed certificate for tls-only mount
  + add CentOS 8 support
- from version 1.24
  + Fix the malformed certificate info
  + bump the release id to 3
  + Use IMDSv1 by default, and use IMDSv2 where required
  + Revert "Use IMDSv1 by default, and fall back to IMDSv2 if necessary"
  + Use IMDSv1 by default, and fall back to IMDSv2 if necessary
  + Modify rhel8-support.sh to handle Fedora as well, and rename it
  + Remove which from DEB package dependency
  + List which as dependency to search command exec path
  + Enable region sourcing from efs-utils configuration file and fix
    stunnel exec path issue in openSUSE
  + Update rpm changelog for v1.23-2, fix circleCI build issue
- from version 1.23
  + Add support for Amazon Elastic Container Service
- from version 1.22
  + Improvements to metadata retrieval and IAM authentication
- from version 1.21
  + Improvements to auth and access point support
- from version 1.20
  + Fixes the mount issue with full DNS name in the AWS China Regions;
    Upgrades unit test coverage version dependency to enable accurate
    python3.8 coverage test
- from version 1.19
  + Added region localization, Integrate repository with CircleCI to enable
    package build visualization, Unit tests bug fixes for python3.5
- from version 1.18
  + Support IAM authentication and access points.
- Add patch to disable mount_efs_test which requires networking
  + disable_mount_efs_test.patch
- Add openssl to BuildRequires, required for testsuite
- Update Requires from requirements.txt
* Tue Nov  3 2020 Franck Bui <fbui@suse.com>
- Drop '-f' option with %%service_del_preun/%%service_del_postun
  With %%service_del_preun, the option is already ignored with as
  support for DISABLE_STOP_ON_REMOVAL has been dropped.
  With %%service_del_postun, this option shouldn't be needed besides
  very few special cases. But this package doesn't seem to belong to
  this category.
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut through the -mini flavors.
* Tue Dec 17 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.17
  + Added support for Python 3
- Enable testsuite which now passes on Python 3
- Update BuildRequires from requirements.txt
* Thu Dec  5 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.16
  + Support Python 3 for tests
- from version 1.15
  + Properly support Python3
- from version 1.14
  + Tolerate EFS state directory existing during mount
- from version 1.13
  + Change watchdog configuration so it stops after all file systems are unmounted
- from version 1.12
  + Update stunnel idle timeout
  * The default stunnel idle timeout is many hours. By setting it to a value based
    on the NFS lease length we can recover from network partitions sooner.
- from version 1.11
  + Add support for RHEL8
  * Fixes Python shebangs to work on systems without a default "python" version.
  * Fixes watchdog process not being properly started on systemd systems.
- from version 1.10
  + Update to default configuration that disables OCSP
  * To use OCSP, the client accessing EFS must be able to reach the Amazon Certificate
    Authority (CA). To maximize file system availability in the event that the CA is
    not reachable from your VPC, the EFS mount helper no longer enables OCSP by default.
- Don't enable testsuite as it is currently failing
  + https://github.com/aws/efs-utils/issues/24
- Drop patches merged upstream
  + efs-switchparser.patch
- Update BuildRequires from requirements.txt
* Tue Apr  9 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.7
  + subprocess usage: explicitly pass `close_fds = True`
  + state_file_dir: choose safe default mode, make mode configurable
  + choose_tls_port(): reuse socket and explicitly close it in all cases
  + watchdog: be robust against unrelated localhost based nfs mounts
- Drop hardening patches merged upstream
  + 0001-subprocess-usage-explicitly-pass-close_fds-True.patch
  + 0002-state_file_dir-choose-safe-default-mode-make-mode-co.patch
  + 0003-pytest-adjust-tests-to-new-state_file_dir_mode-confi.patch
  + 0004-choose_tls_port-reuse-socket-and-explicitly-close-it.patch
  + 0005-watchdog-be-robust-against-unrelated-localhost-based.patch
- from version 1.6
  + fix for additional unexpected arguments
  + add test for additional unexpected arguments
* Wed Apr  3 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Include hardening and robustness fixes from security audit (bsc#1125133)
  + 0001-subprocess-usage-explicitly-pass-close_fds-True.patch
  + 0002-state_file_dir-choose-safe-default-mode-make-mode-co.patch
  + 0003-pytest-adjust-tests-to-new-state_file_dir_mode-confi.patch
  + 0004-choose_tls_port-reuse-socket-and-explicitly-close-it.patch
  + 0005-watchdog-be-robust-against-unrelated-localhost-based.patch
* Thu Feb 14 2019 Robert Schweikert <rjschwei@suse.com>
- Rename from amazon-efs-utils to aws-efs-utils
* Thu Feb 14 2019 Robert Schweikert <rjschwei@suse.com>
- Support Python 3.2 and later
  + Add efs-switchparser.patch
  + SafeConfigParser is no longer available, use ConfigParser
* Mon Feb 11 2019 Jan Engelhardt <jengelh@inai.de>
- Ensure neutrality of descriptions.
* Sat Feb  9 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build (bsc#1101451, fate#327220, bsc#1124652, fate#327221)
  + Version 1.5
